Received: from gcds4003.gcd.de (mail.gcd.de [194.162.100.194]) by hub.org (8.9.3/8.9.3) with ESMTP id LAA70759 for ; Wed, 12 Jan 2000 11:33:22 -0500 (EST) (envelope-from rluettecke@gcd.de) Received: from gcdw4129 (gcdw4129.gcd.de [192.168.4.129]) by gcds4003.gcd.de (8.9.3/8.9.3) with SMTP id RAA04326 for ; Wed, 12 Jan 2000 17:32:51 +0100 Message-ID: <009201bf5d1c$60bf9920$8104a8c0@gcdw4129.gcd.de> From: "=?iso-8859-1?Q?Rolf_L=FCttecke?=" To: Subject: Slow down on Import Date: Wed, 12 Jan 2000 17:45:05 +0100 MIME-Version: 1.0 Content-Type: text/plain; charset="iso-8859-1" Content-Transfer-Encoding: 8bit X-Priority: 3 X-MSMail-Priority: Normal X-Mailer: Microsoft Outlook Express 4.72.2106.4 X-MimeOLE: Produced By Microsoft MimeOLE V4.72.2106.4 Hi folks, first some techn. data: SNI-Primergy w/ PII-333, 128Meg and SCSI-devices, Linux 2.0.36 The following strange behaviour comes up since upgrading to version 6.5.3 + FreeFile-Patch (hi Tom): When re-importing a dumped database the job is normally done in roundabout 8 seconds. When you drop the database and repeat the step a few times, the speed slows down to at least 1.5 minutes. Example: # for i in 1 2 3 4 5 # do # destroydb xyz # createdb xyz # time psql xyz < ./import.db (small table / 10.000 rows) # (output from time: 8.2 seconds up to 1.5 minutes) # done There is no additional load on that machine. The main application (MS-Access w/ ODBC xx.0006) seems sleeping during database- search - so we tried to figure out the problem and made at least the above test directly on that machine. Last hint: A complete copy from "/opt/pgsql" transferred to a another machine shows the same problem. What´s wrong? Any ideas? Regards -Rolf